@@ -47,6 +47,30 @@ link_inverse.default <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.gam <- function(x, ...) {
+  li <- tryCatch({
+    .gam_family(x)$linkinv
+  },
+  error = function(x) {
+    NULL
+  }
+  )
+
+  if (is.null(li)) {
+    mi <- .gam_family(x)
+    if (.obj_has_name(mi, "linfo")) {
+      if (.obj_has_name(mi$linfo, "linkinv"))
+        li <- mi$linfo$linkinv
+      else
+        li <- mi$linfo[[1]]$linkinv
+    }
+  }
+
+  li
+}
+
+
 #' @export
 link_inverse.glm <- function(x, ...) {
   tryCatch({
@@ -78,18 +102,6 @@ link_inverse.gamlss <- function(x, ...) {
 }
 
 
-#' @export
-link_inverse.gam <- function(x, ...) {
-  tryCatch({
-    stats::family(x)$linkinv
-  },
-  error = function(x) {
-    NULL
-  }
-  )
-}
-
-
 #' @export
 link_inverse.lm <- function(x, ...) {
   stats::gaussian(link = "identity")$linkinv
