@@ -1,4 +1,6 @@
-if (require("testthat") && require("insight") && require("gam")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("gam")) {
   context("insight, gam")
 
   data(kyphosis)
@@ -41,13 +43,31 @@ if (require("testthat") && require("insight") && require("gam")) {
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "Kyphosis", conditional = c("s(Age, 4)", "Number")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("Kyphosis", "s(Age, 4)", "Number"))
+    expect_equal(
+      find_terms(m1),
+      list(
+        response = "Kyphosis",
+        conditional = c("s(Age, 4)", "Number")
+      )
+    )
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c("Kyphosis", "s(Age, 4)", "Number")
+    )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = "Kyphosis", conditional = c("Age", "Number")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("Kyphosis", "Age", "Number"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "Kyphosis",
+        conditional = c("Age", "Number")
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("Kyphosis", "Age", "Number")
+    )
   })
 
   test_that("n_obs", {
@@ -67,7 +87,10 @@ if (require("testthat") && require("insight") && require("gam")) {
       )
     )
     expect_equal(nrow(get_parameters(m1)), 3)
-    expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "Number", "s(Age, 4)"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c("(Intercept)", "Number", "s(Age, 4)")
+    )
   })
 
   test_that("is_multivariate", {
@@ -78,4 +101,7 @@ if (require("testthat") && require("insight") && require("gam")) {
     expect_equal(find_algorithm(m1), list(algorithm = "IWLS"))
   })
 
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "F-statistic")
+  })
 }
