@@ -1,10 +1,13 @@
-if (require("testthat") && require("insight") && require("survival")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("survival")) {
   context("insight, coxph")
 
   data("lung")
   lung <- subset(lung, subset = ph.ecog %in% 0:2)
   lung$sex <- factor(lung$sex, labels = c("male", "female"))
-  lung$ph.ecog <- factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
+  lung$ph.ecog <-
+    factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
 
   m1 <- coxph(Surv(time, status) ~ sex + age + ph.ecog, data = lung)
 
@@ -28,20 +31,38 @@ if (require("testthat") && require("insight") && require("survival")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 226)
-    expect_equal(colnames(get_data(m1)), c("time", "status", "Surv(time, status)", "sex", "age", "ph.ecog"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c(
+        "time",
+        "status",
+        "Surv(time, status)",
+        "sex",
+        "age",
+        "ph.ecog"
+      )
+    )
   })
 
   test_that("find_formula", {
     expect_length(find_formula(m1), 1)
     expect_equal(
       find_formula(m1),
-      list(conditional = as.formula("Surv(time, status) ~ sex + age + ph.ecog"))
+      list(conditional = as.formula(
+        "Surv(time, status) ~ sex + age + ph.ecog"
+      ))
     )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = c("time", "status"), conditional = c("sex", "age", "ph.ecog")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("time", "status", "sex", "age", "ph.ecog"))
+    expect_equal(find_variables(m1), list(
+      response = c("time", "status"),
+      conditional = c("sex", "age", "ph.ecog")
+    ))
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("time", "status", "sex", "age", "ph.ecog")
+    )
   })
 
   test_that("n_obs", {
@@ -64,7 +85,10 @@ if (require("testthat") && require("insight") && require("survival")) {
       )
     )
     expect_equal(nrow(get_parameters(m1)), 4)
-    expect_equal(get_parameters(m1)$parameter, c("sexfemale", "age", "ph.ecogok", "ph.ecoglimited"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c("sexfemale", "age", "ph.ecogok", "ph.ecoglimited")
+    )
   })
 
   test_that("find_terms", {
@@ -76,4 +100,8 @@ if (require("testthat") && require("insight") && require("survival")) {
       )
     )
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "z-statistic")
+  })
 }
