@@ -1,17 +1,32 @@
-if (require("testthat") && require("insight") && require("feisr")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("feisr")) {
   context("insight, feisr")
 
   data(mwp)
-  m1 <- feis(lnw ~ marry + enrol + as.factor(yeargr) | exp + I(exp^2), data = mwp, id = "id", robust = TRUE)
+  m1 <-
+    feis(
+      lnw ~ marry + enrol + as.factor(yeargr) |
+        exp + I(exp^2),
+      data = mwp,
+      id = "id",
+      robust = TRUE
+    )
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
   })
 
   test_that("find_predictors", {
-    expect_identical(find_predictors(m1), list(conditional = c("marry", "enrol", "yeargr"), slopes = "exp"))
+    expect_identical(find_predictors(m1), list(
+      conditional = c("marry", "enrol", "yeargr"),
+      slopes = "exp"
+    ))
     expect_identical(find_predictors(m1, effects = "random"), list(random = "id"))
-    expect_identical(find_predictors(m1, effects = "all", flatten = TRUE), c("marry", "enrol", "yeargr", "exp", "id"))
+    expect_identical(
+      find_predictors(m1, effects = "all", flatten = TRUE),
+      c("marry", "enrol", "yeargr", "exp", "id")
+    )
   })
 
   test_that("find_random", {
@@ -31,7 +46,10 @@ if (require("testthat") && require("insight") && require("feisr")) {
   })
 
   test_that("get_predictors", {
-    expect_equal(colnames(get_predictors(m1)), c("marry", "enrol", "yeargr", "exp"))
+    expect_equal(
+      colnames(get_predictors(m1)),
+      c("marry", "enrol", "yeargr", "exp")
+    )
   })
 
   test_that("link_inverse", {
@@ -40,7 +58,10 @@ if (require("testthat") && require("insight") && require("feisr")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 3100)
-    expect_equal(colnames(get_data(m1)), c("lnw", "marry", "enrol", "yeargr", "exp", "id"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("lnw", "marry", "enrol", "yeargr", "exp", "id")
+    )
   })
 
   test_that("find_formula", {
@@ -56,23 +77,43 @@ if (require("testthat") && require("insight") && require("feisr")) {
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(
-      response = "lnw",
-      conditional = c("marry", "enrol", "as.factor(yeargr)"),
-      slopes = c("exp", "I(exp^2)"),
-      random = "id"
-    ))
-    expect_equal(find_terms(m1, flatten = TRUE), c("lnw", "marry", "enrol", "as.factor(yeargr)", "exp", "I(exp^2)", "id"))
+    expect_equal(
+      find_terms(m1),
+      list(
+        response = "lnw",
+        conditional = c("marry", "enrol", "as.factor(yeargr)"),
+        slopes = c("exp", "I(exp^2)"),
+        random = "id"
+      )
+    )
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c(
+        "lnw",
+        "marry",
+        "enrol",
+        "as.factor(yeargr)",
+        "exp",
+        "I(exp^2)",
+        "id"
+      )
+    )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(
-      response = "lnw",
-      conditional = c("marry", "enrol", "yeargr"),
-      slopes = "exp",
-      random = "id"
-    ))
-    expect_equal(find_variables(m1, flatten = TRUE), c("lnw", "marry", "enrol", "yeargr", "exp", "id"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "lnw",
+        conditional = c("marry", "enrol", "yeargr"),
+        slopes = "exp",
+        random = "id"
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("lnw", "marry", "enrol", "yeargr", "exp", "id")
+    )
   })
 
   test_that("n_obs", {
@@ -87,14 +128,35 @@ if (require("testthat") && require("insight") && require("feisr")) {
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = c("marry", "enrol", "as.factor(yeargr)2", "as.factor(yeargr)3", "as.factor(yeargr)4", "as.factor(yeargr)5")
+        conditional = c(
+          "marry",
+          "enrol",
+          "as.factor(yeargr)2",
+          "as.factor(yeargr)3",
+          "as.factor(yeargr)4",
+          "as.factor(yeargr)5"
+        )
       )
     )
     expect_equal(nrow(get_parameters(m1)), 6)
-    expect_equal(get_parameters(m1)$parameter, c("marry", "enrol", "as.factor(yeargr)2", "as.factor(yeargr)3", "as.factor(yeargr)4", "as.factor(yeargr)5"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c(
+        "marry",
+        "enrol",
+        "as.factor(yeargr)2",
+        "as.factor(yeargr)3",
+        "as.factor(yeargr)4",
+        "as.factor(yeargr)5"
+      )
+    )
   })
 
   test_that("is_multivariate", {
     expect_false(is_multivariate(m1))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+  })
 }
