@@ -1,4 +1,6 @@
-if (require("testthat") && require("insight") && require("lfe")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("lfe")) {
   context("insight, lfe")
 
   x <- rnorm(1000)
@@ -13,23 +15,36 @@ if (require("testthat") && require("insight") && require("lfe")) {
   x3 <- rnorm(length(x))
   x4 <- sample(12, length(x), replace = TRUE)
 
-  Q <- 0.3 * x3 + x + 0.2 * x2 + id.eff[id] + 0.3 * log(x4) - 0.3 * y + rnorm(length(x), sd = 0.3)
-  W <- 0.7 * x3 - 2 * x + 0.1 * x2 - 0.7 * id.eff[id] + 0.8 * cos(x4) - 0.2 * y + rnorm(length(x), sd = 0.6)
+  Q <-
+    0.3 * x3 + x + 0.2 * x2 + id.eff[id] + 0.3 * log(x4) - 0.3 * y + rnorm(length(x), sd = 0.3)
+  W <-
+    0.7 * x3 - 2 * x + 0.1 * x2 - 0.7 * id.eff[id] + 0.8 * cos(x4) - 0.2 * y + rnorm(length(x), sd = 0.6)
 
   # add them to the outcome
   y <- y + Q + W
   dat <- data.frame(y, x, x2, x3, x4, id, firm, Q, W)
 
-  m1 <- felm(y ~ x + x2 | id + firm | (Q | W ~ x3 + factor(x4)), data = dat)
+  m1 <-
+    felm(y ~ x + x2 |
+      id + firm | (Q | W ~ x3 + factor(x4)), data = dat)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
   })
 
   test_that("find_predictors", {
-    expect_identical(find_predictors(m1), list(conditional = c("x", "x2"), instruments = c("Q", "W", "x3", "x4")))
+    expect_identical(
+      find_predictors(m1),
+      list(
+        conditional = c("x", "x2"),
+        instruments = c("Q", "W", "x3", "x4")
+      )
+    )
     expect_identical(find_predictors(m1, effects = "random"), list(random = c("id", "firm")))
-    expect_identical(find_predictors(m1, effects = "all", flatten = TRUE), c("x", "x2", "id", "firm", "Q", "W", "x3", "x4"))
+    expect_identical(
+      find_predictors(m1, effects = "all", flatten = TRUE),
+      c("x", "x2", "id", "firm", "Q", "W", "x3", "x4")
+    )
   })
 
   test_that("find_random", {
@@ -49,7 +64,10 @@ if (require("testthat") && require("insight") && require("lfe")) {
   })
 
   test_that("get_predictors", {
-    expect_equal(colnames(get_predictors(m1)), c("x", "x2", "Q", "W", "x3", "x4"))
+    expect_equal(
+      colnames(get_predictors(m1)),
+      c("x", "x2", "Q", "W", "x3", "x4")
+    )
   })
 
   test_that("link_inverse", {
@@ -58,7 +76,10 @@ if (require("testthat") && require("insight") && require("lfe")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 1000)
-    expect_equal(colnames(get_data(m1)), c("y", "x", "x2", "id", "firm", "Q", "W", "x3", "x4"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("y", "x", "x2", "id", "firm", "Q", "W", "x3", "x4")
+    )
   })
 
   test_that("find_formula", {
@@ -81,20 +102,29 @@ if (require("testthat") && require("insight") && require("lfe")) {
         conditional = c("x", "x2"),
         random = c("id", "firm"),
         instruments = c("(Q", "W  x3", "factor(x4))")
-      ))
-    expect_equal(find_terms(m1, flatten = TRUE),
-                 c("y", "x", "x2", "id", "firm", "(Q", "W  x3", "factor(x4))"))
+      )
+    )
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c("y", "x", "x2", "id", "firm", "(Q", "W  x3", "factor(x4))")
+    )
   })
 
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(
-      response = "y",
-      conditional = c("x", "x2"),
-      random = c("id", "firm"),
-      instruments = c("Q", "W", "x3", "x4")
-    ))
-    expect_equal(find_variables(m1, flatten = TRUE), c("y", "x", "x2", "id", "firm", "Q", "W", "x3", "x4"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "y",
+        conditional = c("x", "x2"),
+        random = c("id", "firm"),
+        instruments = c("Q", "W", "x3", "x4")
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("y", "x", "x2", "id", "firm", "Q", "W", "x3", "x4")
+    )
   })
 
 
@@ -109,15 +139,20 @@ if (require("testthat") && require("insight") && require("lfe")) {
   test_that("find_parameters", {
     expect_equal(
       find_parameters(m1),
-      list(
-        conditional = c("x", "x2", "`Q(fit)`", "`W(fit)`")
-      )
+      list(conditional = c("x", "x2", "`Q(fit)`", "`W(fit)`"))
     )
     expect_equal(nrow(get_parameters(m1)), 4)
-    expect_equal(get_parameters(m1)$parameter, c("x", "x2", "`Q(fit)`", "`W(fit)`"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c("x", "x2", "`Q(fit)`", "`W(fit)`")
+    )
   })
 
   test_that("is_multivariate", {
     expect_false(is_multivariate(m1))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+  })
 }
