@@ -1,9 +1,13 @@
-if (require("testthat") && require("insight") && require("pscl")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("pscl")) {
   context("insight, model_info")
 
   data("bioChemists")
 
-  m1 <- hurdle(art ~ fem + mar + kid5 + ment | kid5 + phd, data = bioChemists)
+  m1 <-
+    hurdle(art ~ fem + mar + kid5 + ment |
+      kid5 + phd, data = bioChemists)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_poisson)
@@ -11,8 +15,17 @@ if (require("testthat") && require("insight") && require("pscl")) {
   })
 
   test_that("find_predictors", {
-    expect_identical(find_predictors(m1), list(conditional = c("fem", "mar", "kid5", "ment"), zero_inflated = c("kid5", "phd")))
-    expect_identical(find_predictors(m1, flatten = TRUE), c("fem", "mar", "kid5", "ment", "phd"))
+    expect_identical(
+      find_predictors(m1),
+      list(
+        conditional = c("fem", "mar", "kid5", "ment"),
+        zero_inflated = c("kid5", "phd")
+      )
+    )
+    expect_identical(
+      find_predictors(m1, flatten = TRUE),
+      c("fem", "mar", "kid5", "ment", "phd")
+    )
     expect_null(find_predictors(m1, effects = "random"))
   })
 
@@ -30,7 +43,10 @@ if (require("testthat") && require("insight") && require("pscl")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 915)
-    expect_equal(colnames(get_data(m1)), c("art", "fem", "mar", "kid5", "ment", "phd"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("art", "fem", "mar", "kid5", "ment", "phd")
+    )
   })
 
   test_that("find_formula", {
@@ -45,8 +61,18 @@ if (require("testthat") && require("insight") && require("pscl")) {
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = "art", conditional = c("fem", "mar", "kid5", "ment"), zero_inflated = c("kid5", "phd")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("art", "fem", "mar", "kid5", "ment", "phd"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "art",
+        conditional = c("fem", "mar", "kid5", "ment"),
+        zero_inflated = c("kid5", "phd")
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("art", "fem", "mar", "kid5", "ment", "phd")
+    )
   })
 
   test_that("n_obs", {
@@ -61,13 +87,31 @@ if (require("testthat") && require("insight") && require("pscl")) {
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = c("count_(Intercept)", "count_femWomen", "count_marMarried", "count_kid5", "count_ment"),
+        conditional = c(
+          "count_(Intercept)",
+          "count_femWomen",
+          "count_marMarried",
+          "count_kid5",
+          "count_ment"
+        ),
         zero_inflated = c("zero_(Intercept)", "zero_kid5", "zero_phd")
       )
     )
     expect_equal(nrow(get_parameters(m1)), 8)
     expect_equal(nrow(get_parameters(m1, component = "zi")), 3)
-    expect_equal(get_parameters(m1)$parameter, c("count_(Intercept)", "count_femWomen", "count_marMarried", "count_kid5", "count_ment", "zero_(Intercept)", "zero_kid5", "zero_phd"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c(
+        "count_(Intercept)",
+        "count_femWomen",
+        "count_marMarried",
+        "count_kid5",
+        "count_ment",
+        "zero_(Intercept)",
+        "zero_kid5",
+        "zero_phd"
+      )
+    )
   })
 
   test_that("is_multivariate", {
@@ -84,4 +128,8 @@ if (require("testthat") && require("insight") && require("pscl")) {
       )
     )
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "z-statistic")
+  })
 }
