@@ -1,20 +1,46 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
 if (.runThisTest || Sys.getenv("USER") == "travis") {
-
   if (require("testthat") && require("insight") && require("plm")) {
     context("insight, model_info")
 
     data(Crime)
-    m1 <- plm(lcrmrte ~ lprbarr + factor(year) | . - lprbarr + lmix, data = Crime, model = "random")
+    m1 <-
+      plm(
+        lcrmrte ~ lprbarr + factor(year) |
+          . - lprbarr + lmix,
+        data = Crime,
+        model = "random"
+      )
+
+    # data
+    set.seed(123)
+    library(plm)
+    data("Produc", package = "plm")
+
+    # model
+    m2 <- plm::plm(
+      formula = log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp,
+      data = Produc,
+      index = c("state", "year")
+    )
 
     test_that("model_info", {
       expect_true(model_info(m1)$is_linear)
     })
 
     test_that("find_predictors", {
-      expect_identical(find_predictors(m1), list(conditional = c("lprbarr", "year"), instruments = c("lprbarr", "lmix")))
-      expect_identical(find_predictors(m1, flatten = TRUE), c("lprbarr", "year", "lmix"))
+      expect_identical(
+        find_predictors(m1),
+        list(
+          conditional = c("lprbarr", "year"),
+          instruments = c("lprbarr", "lmix")
+        )
+      )
+      expect_identical(
+        find_predictors(m1, flatten = TRUE),
+        c("lprbarr", "year", "lmix")
+      )
       expect_null(find_predictors(m1, effects = "random"))
     })
 
@@ -44,7 +70,10 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
 
     test_that("get_data", {
       expect_equal(nrow(get_data(m1)), 630)
-      expect_equal(colnames(get_data(m1)), c("lcrmrte", "lprbarr", "year", "lmix"))
+      expect_equal(
+        colnames(get_data(m1)),
+        c("lcrmrte", "lprbarr", "year", "lmix")
+      )
     })
 
     test_that("find_formula", {
@@ -59,8 +88,18 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
     })
 
     test_that("find_variables", {
-      expect_equal(find_variables(m1), list(response = "lcrmrte", conditional = c("lprbarr", "year"), instruments = c("lprbarr", "lmix")))
-      expect_equal(find_variables(m1, flatten = TRUE), c("lcrmrte", "lprbarr", "year", "lmix"))
+      expect_equal(
+        find_variables(m1),
+        list(
+          response = "lcrmrte",
+          conditional = c("lprbarr", "year"),
+          instruments = c("lprbarr", "lmix")
+        )
+      )
+      expect_equal(
+        find_variables(m1, flatten = TRUE),
+        c("lcrmrte", "lprbarr", "year", "lmix")
+      )
     })
 
     test_that("n_obs", {
@@ -75,7 +114,16 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
       expect_equal(
         find_parameters(m1),
         list(
-          conditional = c("(Intercept)", "lprbarr", "factor(year)82", "factor(year)83", "factor(year)84", "factor(year)85", "factor(year)86", "factor(year)87")
+          conditional = c(
+            "(Intercept)",
+            "lprbarr",
+            "factor(year)82",
+            "factor(year)83",
+            "factor(year)84",
+            "factor(year)85",
+            "factor(year)86",
+            "factor(year)87"
+          )
         )
       )
       expect_equal(nrow(get_parameters(m1)), 8)
@@ -84,5 +132,10 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
     test_that("is_multivariate", {
       expect_false(is_multivariate(m1))
     })
+
+    test_that("find_statistic", {
+      expect_identical(find_statistic(m1), "z-statistic")
+      expect_identical(find_statistic(m2), "t-statistic")
+    })
   }
 }
